@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 #
-# Author: Don Welch
+# Author: Don Welch, Naga Samrat Chowdary Narla, Goutam Kodu
 #
 # Thanks to Henrique M. Holschuh <hmh@debian.org> for various security patches
 #
@@ -26,6 +26,7 @@ from __future__ import generators
 # Std Lib
 import sys
 import os
+import grp
 import fnmatch
 import tempfile
 import socket
@@ -58,8 +59,35 @@ import pexpect
 BIG_ENDIAN = 0
 LITTLE_ENDIAN = 1
 
+def addgroup():
+    lis = []
+    try:
+        fp=open('/etc/cups/cupsd.conf')
+    except IOError:
+        try:
+            if "root" != grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid).gr_name:
+                return [grp.getgrgid(os.stat('/etc/cups/cupsd.conf').st_gid).gr_name]
+        except OSError:
+            return lis
 
+    try:
+        lis = ((re.findall('SystemGroup [\w* ]*',fp.read()))[0].replace('SystemGroup ','')).split(' ')
+    except IndexError:
+        return lis
 
+    if 'root' in lis:
+        lis.remove('root')
+    fp.close()
+    return lis
+
+def list_to_string(lis):
+    if len(lis) == 0:
+        return ""
+    if len(lis) == 1:
+        return str("\""+lis[0]+"\"")
+    if len(lis) >= 1:
+        return "\""+"\", \"".join(lis)+"\" and \""+str(lis.pop())+"\""
+        
 def lock(f):
     log.debug("Locking: %s" % f.name)
     try:
@@ -1601,6 +1629,39 @@ def su_sudo():
 
     return su_sudo_str
 
+# This function returns the distro name and distro version. 
+#This is provided to check on Fedora 14 in pkit.py file for Plugin-installation. 
+#is_su variable is used to provide a check on Fedora 8 
+def os_release():
+    os_name = None;
+    os_version = None;
+    is_su = None;
+    if which('lsb_release'):
+       name = os.popen('lsb_release -i | cut -f 2')
+       os_name = name.read().strip()
+       name.close()
+       version = os.popen('lsb_release -r | cut -f 2')
+       os_version=version.read().strip()
+       version.close()
+       is_su = True
+    else:
+       name = os.popen('cat /etc/issue | cut -c 1-6 | head -n 1')
+       os_name = name.read().strip()
+       name.close()
+       version1=os.popen('cat /etc/issue | cut -c 16 | head -n 1')
+       version2=version1.read().strip()
+       version1.close()
+       if (version2 == '1'):
+           version=os.popen('cat /etc/issue | cut -c 16-17 | head -n 1')
+           is_su = True
+       else: 
+           version=os.popen('cat /etc/issue | cut -c 16 | head -n 1')
+           is_su = False
+       os_version=version.read().strip()
+       version.close()
+
+    return os_name,os_version,is_su 
+    
 
 #
 # Removes HTML or XML character references and entities from a text string.
