@@ -21,6 +21,7 @@
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+  Author: Naga Samrat Chowdary Narla,
 \*****************************************************************************/
 
 #include "hpmud.h"
@@ -207,6 +208,11 @@ enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) service_to_channel(mud
    {
       *index = HPMUD_MARVELL_FAX_CHANNEL;
    }
+   else if (strncasecmp(sn, "hp-ledm-scan", 12) == 0)
+   {
+      *index = HPMUD_LEDM_SCAN_CHANNEL;
+      BUG("io/hpmud/hpmud.c: service_to_channel(): sn=%s\n", sn);   
+   }
    /* All the following services require MLC/1284.4. */
    else if (pd->io_mode == HPMUD_RAW_MODE || pd->io_mode == HPMUD_UNI_MODE)
    {
