@@ -1,4 +1,4 @@
-/************************************************************************************\
+/********************************************************************************************\
 
   common.c - common code for scl, pml, and soap backends
 
@@ -21,9 +21,9 @@
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION 
   WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-  Contributing Authors: David Paschal, Don Welch, David Suffield 
+  Contributing Authors: David Paschal, Don Welch, David Suffield, Naga Samrat Chowdary Narla
 
-\************************************************************************************/
+\********************************************************************************************/
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -44,8 +44,8 @@ int __attribute__ ((visibility ("hidden"))) bug(const char *fmt, ...)
    va_start(args, fmt);
    if ((n = vsnprintf(buf, 256, fmt, args)) == -1)
       buf[255] = 0;     /* output was truncated */
-   syslog(LOG_WARNING, buf);
-   DBG(2, buf);
+   syslog(LOG_WARNING, "%s", buf);
+   DBG(2, "%s", buf);
    va_end(args);
    return n;
 }
@@ -66,7 +66,7 @@ void __attribute__ ((visibility ("hidden"))) sysdump(const void *data, int size)
     for(n=1;n<=size;n++) {
         if (n%16 == 1) {
             /* store address for this line */
-            snprintf(addrstr, sizeof(addrstr), "%.4x", (p-(unsigned char *)data) && 0xffff);
+            snprintf(addrstr, sizeof(addrstr), "%.4d", (int)((p-(unsigned char *)data) & 0xffff));
         }
             
         c = *p;
@@ -84,7 +84,7 @@ void __attribute__ ((visibility ("hidden"))) sysdump(const void *data, int size)
 
         if(n%16 == 0) { 
             /* line completed */
-            DBG(6, "[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
+            DBG_SZ("[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
             hexstr[0] = 0;
             charstr[0] = 0;
         }
@@ -93,7 +93,7 @@ void __attribute__ ((visibility ("hidden"))) sysdump(const void *data, int size)
 
     if (strlen(hexstr) > 0) {
         /* print rest of buffer if not empty */
-        DBG(6, "[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
+        DBG_SZ("[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
     }
 }
 
@@ -113,7 +113,7 @@ void __attribute__ ((visibility ("hidden"))) bugdump(const void *data, int size)
     for(n=1;n<=size;n++) {
         if (n%16 == 1) {
             /* store address for this line */
-            snprintf(addrstr, sizeof(addrstr), "%.4x", (p-(unsigned char *)data) && 0xffff);
+            snprintf(addrstr, sizeof(addrstr), "%.4d", (int)((p-(unsigned char *)data) & 0xffff));
         }
             
         c = *p;
@@ -131,7 +131,7 @@ void __attribute__ ((visibility ("hidden"))) bugdump(const void *data, int size)
 
         if(n%16 == 0) { 
             /* line completed */
-            bug("[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
+            BUG_SZ("[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
             hexstr[0] = 0;
             charstr[0] = 0;
         }
@@ -140,7 +140,7 @@ void __attribute__ ((visibility ("hidden"))) bugdump(const void *data, int size)
 
     if (strlen(hexstr) > 0) {
         /* print rest of buffer if not empty */
-        bug("[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
+        BUG_SZ("[%4.4s]   %-50.50s  %s\n", addrstr, hexstr, charstr);
     }
 }
 
